@@ -180,6 +180,7 @@ pub fn module_params_set(client: ClientRef, mut args: Split<&str>) {
                     let (changes, success) = change_from_path(path, values, &|x| {
                         match &x.ty {
                             UIFieldType::Header => false,
+                            UIFieldType::Label => false,
                             UIFieldType::Collapsable(_) => false,
                             UIFieldType::Array(_) => false,
 
@@ -393,6 +394,11 @@ pub fn module_list_params(client: ClientRef, mut args: Split<&str>) {
                                 println!("{}Type: Header", tabs);
                             }
 
+                            UIFieldValue::Label(str) => {
+                                println!("{}Type: Label", tabs);
+                                println!("{}Value: {}", tabs, str);
+                            }
+
                             UIFieldValue::InputFieldFloat(f) | UIFieldValue::ValueSliderFloat(f) => {
                                 println!("{}Type: Float", tabs);
                                 println!("{}Value: {}", tabs, f);
@@ -451,7 +457,7 @@ pub fn module_list_params(client: ClientRef, mut args: Split<&str>) {
                             }
 
                             UIFieldValue::Array(array) => {
-                                println!("{}Type: Submenu", tabs);
+                                println!("{}Type: Array", tabs);
                                 println!("{}Items:", tabs);
 
                                 for (index, array_item) in array.into_iter().enumerate() {
